cmd_/home/turmio/Downloads/buildroot-2011.11/output/toolchain/linux/include/drm/.install := perl scripts/headers_install.pl /home/turmio/Downloads/buildroot-2011.11/output/toolchain/linux-3.1.4/include/drm /home/turmio/Downloads/buildroot-2011.11/output/toolchain/linux/include/drm arm drm.h drm_mode.h drm_sarea.h i810_drm.h i915_drm.h mga_drm.h nouveau_drm.h r128_drm.h radeon_drm.h savage_drm.h sis_drm.h via_drm.h vmwgfx_drm.h; perl scripts/headers_install.pl /home/turmio/Downloads/buildroot-2011.11/output/toolchain/linux-3.1.4/include/drm /home/turmio/Downloads/buildroot-2011.11/output/toolchain/linux/include/drm arm ; for F in ; do echo "\#include <asm-generic/$$F>" > /home/turmio/Downloads/buildroot-2011.11/output/toolchain/linux/include/drm/$$F; done; touch /home/turmio/Downloads/buildroot-2011.11/output/toolchain/linux/include/drm/.install
