cmd_/home/turmio/Downloads/buildroot-2011.11/output/toolchain/linux/include/linux/caif/.install := perl scripts/headers_install.pl /home/turmio/Downloads/buildroot-2011.11/output/toolchain/linux-3.1.4/include/linux/caif /home/turmio/Downloads/buildroot-2011.11/output/toolchain/linux/include/linux/caif arm caif_socket.h if_caif.h; perl scripts/headers_install.pl /home/turmio/Downloads/buildroot-2011.11/output/toolchain/linux-3.1.4/include/linux/caif /home/turmio/Downloads/buildroot-2011.11/output/toolchain/linux/include/linux/caif arm ; for F in ; do echo "\#include <asm-generic/$$F>" > /home/turmio/Downloads/buildroot-2011.11/output/toolchain/linux/include/linux/caif/$$F; done; touch /home/turmio/Downloads/buildroot-2011.11/output/toolchain/linux/include/linux/caif/.install
