cmd_/home/turmio/Downloads/buildroot-2011.11/output/toolchain/linux/include/linux/tc_act/.install := perl scripts/headers_install.pl /home/turmio/Downloads/buildroot-2011.11/output/toolchain/linux-3.1.4/include/linux/tc_act /home/turmio/Downloads/buildroot-2011.11/output/toolchain/linux/include/linux/tc_act arm tc_csum.h tc_gact.h tc_ipt.h tc_mirred.h tc_nat.h tc_pedit.h tc_skbedit.h; perl scripts/headers_install.pl /home/turmio/Downloads/buildroot-2011.11/output/toolchain/linux-3.1.4/include/linux/tc_act /home/turmio/Downloads/buildroot-2011.11/output/toolchain/linux/include/linux/tc_act arm ; for F in ; do echo "\#include <asm-generic/$$F>" > /home/turmio/Downloads/buildroot-2011.11/output/toolchain/linux/include/linux/tc_act/$$F; done; touch /home/turmio/Downloads/buildroot-2011.11/output/toolchain/linux/include/linux/tc_act/.install
