cmd_/home/turmio/Downloads/buildroot-2011.11/output/toolchain/linux/include/linux/tc_ematch/.install := perl scripts/headers_install.pl /home/turmio/Downloads/buildroot-2011.11/output/toolchain/linux-3.1.4/include/linux/tc_ematch /home/turmio/Downloads/buildroot-2011.11/output/toolchain/linux/include/linux/tc_ematch arm tc_em_cmp.h tc_em_meta.h tc_em_nbyte.h tc_em_text.h; perl scripts/headers_install.pl /home/turmio/Downloads/buildroot-2011.11/output/toolchain/linux-3.1.4/include/linux/tc_ematch /home/turmio/Downloads/buildroot-2011.11/output/toolchain/linux/include/linux/tc_ematch arm ; for F in ; do echo "\#include <asm-generic/$$F>" > /home/turmio/Downloads/buildroot-2011.11/output/toolchain/linux/include/linux/tc_ematch/$$F; done; touch /home/turmio/Downloads/buildroot-2011.11/output/toolchain/linux/include/linux/tc_ematch/.install
