cmd_/home/turmio/Downloads/buildroot-2011.11/output/toolchain/linux/include/linux/can/.install := perl scripts/headers_install.pl /home/turmio/Downloads/buildroot-2011.11/output/toolchain/linux-3.1.4/include/linux/can /home/turmio/Downloads/buildroot-2011.11/output/toolchain/linux/include/linux/can arm bcm.h error.h netlink.h raw.h; perl scripts/headers_install.pl /home/turmio/Downloads/buildroot-2011.11/output/toolchain/linux-3.1.4/include/linux/can /home/turmio/Downloads/buildroot-2011.11/output/toolchain/linux/include/linux/can arm ; for F in ; do echo "\#include <asm-generic/$$F>" > /home/turmio/Downloads/buildroot-2011.11/output/toolchain/linux/include/linux/can/$$F; done; touch /home/turmio/Downloads/buildroot-2011.11/output/toolchain/linux/include/linux/can/.install
