cmd_/home/turmio/Downloads/buildroot-2011.11/output/toolchain/linux/include/scsi/fc/.install := perl scripts/headers_install.pl /home/turmio/Downloads/buildroot-2011.11/output/toolchain/linux-3.1.4/include/scsi/fc /home/turmio/Downloads/buildroot-2011.11/output/toolchain/linux/include/scsi/fc arm fc_els.h fc_fs.h fc_gs.h fc_ns.h; perl scripts/headers_install.pl /home/turmio/Downloads/buildroot-2011.11/output/toolchain/linux-3.1.4/include/scsi/fc /home/turmio/Downloads/buildroot-2011.11/output/toolchain/linux/include/scsi/fc arm ; for F in ; do echo "\#include <asm-generic/$$F>" > /home/turmio/Downloads/buildroot-2011.11/output/toolchain/linux/include/scsi/fc/$$F; done; touch /home/turmio/Downloads/buildroot-2011.11/output/toolchain/linux/include/scsi/fc/.install
