cmd_/home/turmio/Downloads/buildroot-2011.11/output/toolchain/linux/include/asm-generic/.install := perl scripts/headers_install.pl /home/turmio/Downloads/buildroot-2011.11/output/toolchain/linux-3.1.4/include/asm-generic /home/turmio/Downloads/buildroot-2011.11/output/toolchain/linux/include/asm-generic arm auxvec.h bitsperlong.h errno-base.h errno.h fcntl.h int-l64.h int-ll64.h ioctl.h ioctls.h ipcbuf.h mman-common.h mman.h msgbuf.h param.h poll.h posix_types.h resource.h sembuf.h setup.h shmbuf.h shmparam.h siginfo.h signal-defs.h signal.h socket.h sockios.h stat.h statfs.h swab.h termbits.h termios.h types.h ucontext.h unistd.h; perl scripts/headers_install.pl /home/turmio/Downloads/buildroot-2011.11/output/toolchain/linux-3.1.4/include/asm-generic /home/turmio/Downloads/buildroot-2011.11/output/toolchain/linux/include/asm-generic arm ; for F in ; do echo "\#include <asm-generic/$$F>" > /home/turmio/Downloads/buildroot-2011.11/output/toolchain/linux/include/asm-generic/$$F; done; touch /home/turmio/Downloads/buildroot-2011.11/output/toolchain/linux/include/asm-generic/.install
