cmd_/home/turmio/Downloads/buildroot-2011.11/output/toolchain/linux/include/linux/netfilter/ipset/.install := perl scripts/headers_install.pl /home/turmio/Downloads/buildroot-2011.11/output/toolchain/linux-3.1.4/include/linux/netfilter/ipset /home/turmio/Downloads/buildroot-2011.11/output/toolchain/linux/include/linux/netfilter/ipset arm ip_set.h ip_set_bitmap.h ip_set_hash.h ip_set_list.h; perl scripts/headers_install.pl /home/turmio/Downloads/buildroot-2011.11/output/toolchain/linux-3.1.4/include/linux/netfilter/ipset /home/turmio/Downloads/buildroot-2011.11/output/toolchain/linux/include/linux/netfilter/ipset arm ; for F in ; do echo "\#include <asm-generic/$$F>" > /home/turmio/Downloads/buildroot-2011.11/output/toolchain/linux/include/linux/netfilter/ipset/$$F; done; touch /home/turmio/Downloads/buildroot-2011.11/output/toolchain/linux/include/linux/netfilter/ipset/.install
