/* This file is automatically generated by configure.  Do not modify by hand. */
/* Define if compiling with the mibII/vacm_conf module files.  */
#define USING_MIBII_VACM_CONF_MODULE 1
 
/* Define if compiling with the snmpv3/usmConf module files.  */
#define USING_SNMPV3_USMCONF_MODULE 1
 
