/* This file is automatically generated by configure.  Do not modify by hand. */
/*#include "mibgroup/host.h"*/
#include "mibgroup/ucd-snmp/dlmod.h"
/*#include "mibgroup/default_modules.h"*/
#include "mibgroup/host/hr_storage.h"
#include "mibgroup/host/hr_filesys.h"
#include "mibgroup/host/hrSWInstalledTable.h"
#include "mibgroup/host/hrSWRunTable.h"
#include "mibgroup/host/hr_system.h"
#include "mibgroup/host/hr_device.h"
#include "mibgroup/host/hr_other.h"
#include "mibgroup/host/hr_proc.h"
#include "mibgroup/host/hr_network.h"
#include "mibgroup/host/hr_print.h"
#include "mibgroup/host/hr_disk.h"
#include "mibgroup/host/hr_partition.h"
/*#include "mibgroup/snmpv3mibs.h"*/
#include "mibgroup/mibII/snmp_mib.h"
#include "mibgroup/mibII/system_mib.h"
#include "mibgroup/mibII/sysORTable.h"
#include "mibgroup/mibII/vacm_vars.h"
/*#include "mibgroup/util_funcs/Exit.h"*/
/*#include "mibgroup/util_funcs/restart.h"*/
/*#include "mibgroup/hardware/memory.h"*/
#include "mibgroup/host/data_access/swinst.h"
#include "mibgroup/host/data_access/swrun.h"
#include "mibgroup/host/hrSWRunPerfTable.h"
/*#include "mibgroup/hardware/cpu.h"*/
/*#include "mibgroup/mibII/ifTable.h"*/
/*#include "mibgroup/util_funcs.h"*/
#include "mibgroup/snmpv3/snmpMPDStats_5_5.h"
#include "mibgroup/snmpv3/usmStats_5_5.h"
#include "mibgroup/snmpv3/snmpEngine.h"
#include "mibgroup/snmpv3/usmUser.h"
/*#include "mibgroup/mibII/updates.h"*/
/*#include "mibgroup/util_funcs/header_generic.h"*/
#include "mibgroup/mibII/vacm_context.h"
#include "mibgroup/hardware/memory/hw_mem.h"
/*#include "mibgroup/hardware/memory/memory_linux.h"*/
/*#include "mibgroup/host/data_access/swinst_apt.h"*/
/*#include "mibgroup/host/data_access/swrun_procfs_status.h"*/
#include "mibgroup/hardware/cpu/cpu.h"
#include "mibgroup/hardware/cpu/cpu_linux.h"
/*#include "mibgroup/if-mib/ifTable.h"*/
/*#include "mibgroup/util_funcs/header_simple_table.h"*/
#include "mibgroup/if-mib/ifTable/ifTable.h"
#include "mibgroup/if-mib/data_access/interface.h"
/*#include "mibgroup/if-mib/ifTable/ifTable_interface.h"*/
/*#include "mibgroup/if-mib/ifTable/ifTable_data_access.h"*/
/*#include "mibgroup/if-mib/data_access/interface_linux.h"*/
/*#include "mibgroup/if-mib/data_access/interface_ioctl.h"*/
/*#include "mibgroup/ip-mib/data_access/ipaddress.h"*/
/*#include "mibgroup/ip-mib/data_access/ipaddress_common.h"*/
/*#include "mibgroup/ip-mib/data_access/ipaddress_linux.h"*/
/*#include "mibgroup/ip-mib/data_access/ipaddress_ioctl.h"*/
