/* This file is automatically generated by configure.  Do not modify by hand. */
/* Define if compiling with the host module files.  */
#define USING_HOST_MODULE 1
 
/* Define if compiling with the ucd-snmp/dlmod module files.  */
#define USING_UCD_SNMP_DLMOD_MODULE 1
 
/* Define if compiling with the default_modules module files.  */
#define USING_DEFAULT_MODULES_MODULE 1
 
/* Define if compiling with the host/hr_storage module files.  */
#define USING_HOST_HR_STORAGE_MODULE 1
 
/* Define if compiling with the host/hr_filesys module files.  */
#define USING_HOST_HR_FILESYS_MODULE 1
 
/* Define if compiling with the host/hrSWInstalledTable module files.  */
#define USING_HOST_HRSWINSTALLEDTABLE_MODULE 1
 
/* Define if compiling with the host/hrSWRunTable module files.  */
#define USING_HOST_HRSWRUNTABLE_MODULE 1
 
/* Define if compiling with the host/hr_system module files.  */
#define USING_HOST_HR_SYSTEM_MODULE 1
 
/* Define if compiling with the host/hr_device module files.  */
#define USING_HOST_HR_DEVICE_MODULE 1
 
/* Define if compiling with the host/hr_other module files.  */
#define USING_HOST_HR_OTHER_MODULE 1
 
/* Define if compiling with the host/hr_proc module files.  */
#define USING_HOST_HR_PROC_MODULE 1
 
/* Define if compiling with the host/hr_network module files.  */
#define USING_HOST_HR_NETWORK_MODULE 1
 
/* Define if compiling with the host/hr_print module files.  */
#define USING_HOST_HR_PRINT_MODULE 1
 
/* Define if compiling with the host/hr_disk module files.  */
#define USING_HOST_HR_DISK_MODULE 1
 
/* Define if compiling with the host/hr_partition module files.  */
#define USING_HOST_HR_PARTITION_MODULE 1
 
/* Define if compiling with the snmpv3mibs module files.  */
#define USING_SNMPV3MIBS_MODULE 1
 
/* Define if compiling with the mibII/snmp_mib module files.  */
#define USING_MIBII_SNMP_MIB_MODULE 1
 
/* Define if compiling with the mibII/system_mib module files.  */
#define USING_MIBII_SYSTEM_MIB_MODULE 1
 
/* Define if compiling with the mibII/sysORTable module files.  */
#define USING_MIBII_SYSORTABLE_MODULE 1
 
/* Define if compiling with the mibII/vacm_vars module files.  */
#define USING_MIBII_VACM_VARS_MODULE 1
 
/* Define if compiling with the util_funcs/Exit module files.  */
#define USING_UTIL_FUNCS_EXIT_MODULE 1
 
/* Define if compiling with the util_funcs/restart module files.  */
#define USING_UTIL_FUNCS_RESTART_MODULE 1
 
/* Define if compiling with the hardware/memory module files.  */
#define USING_HARDWARE_MEMORY_MODULE 1
 
/* Define if compiling with the host/data_access/swinst module files.  */
#define USING_HOST_DATA_ACCESS_SWINST_MODULE 1
 
/* Define if compiling with the host/data_access/swrun module files.  */
#define USING_HOST_DATA_ACCESS_SWRUN_MODULE 1
 
/* Define if compiling with the host/hrSWRunPerfTable module files.  */
#define USING_HOST_HRSWRUNPERFTABLE_MODULE 1
 
/* Define if compiling with the hardware/cpu module files.  */
#define USING_HARDWARE_CPU_MODULE 1
 
/* Define if compiling with the mibII/ifTable module files.  */
#define USING_MIBII_IFTABLE_MODULE 1
 
/* Define if compiling with the util_funcs module files.  */
#define USING_UTIL_FUNCS_MODULE 1
 
/* Define if compiling with the snmpv3/snmpMPDStats_5_5 module files.  */
#define USING_SNMPV3_SNMPMPDSTATS_5_5_MODULE 1
 
/* Define if compiling with the snmpv3/usmStats_5_5 module files.  */
#define USING_SNMPV3_USMSTATS_5_5_MODULE 1
 
/* Define if compiling with the snmpv3/snmpEngine module files.  */
#define USING_SNMPV3_SNMPENGINE_MODULE 1
 
/* Define if compiling with the snmpv3/usmUser module files.  */
#define USING_SNMPV3_USMUSER_MODULE 1
 
/* Define if compiling with the mibII/updates module files.  */
#define USING_MIBII_UPDATES_MODULE 1
 
/* Define if compiling with the util_funcs/header_generic module files.  */
#define USING_UTIL_FUNCS_HEADER_GENERIC_MODULE 1
 
/* Define if compiling with the mibII/vacm_context module files.  */
#define USING_MIBII_VACM_CONTEXT_MODULE 1
 
/* Define if compiling with the hardware/memory/hw_mem module files.  */
#define USING_HARDWARE_MEMORY_HW_MEM_MODULE 1
 
/* Define if compiling with the hardware/memory/memory_linux module files.  */
#define USING_HARDWARE_MEMORY_MEMORY_LINUX_MODULE 1
 
/* Define if compiling with the host/data_access/swinst_apt module files.  */
#define USING_HOST_DATA_ACCESS_SWINST_APT_MODULE 1
 
/* Define if compiling with the host/data_access/swrun_procfs_status module files.  */
#define USING_HOST_DATA_ACCESS_SWRUN_PROCFS_STATUS_MODULE 1
 
/* Define if compiling with the hardware/cpu/cpu module files.  */
#define USING_HARDWARE_CPU_CPU_MODULE 1
 
/* Define if compiling with the hardware/cpu/cpu_linux module files.  */
#define USING_HARDWARE_CPU_CPU_LINUX_MODULE 1
 
/* Define if compiling with the if-mib/ifTable module files.  */
#define USING_IF_MIB_IFTABLE_MODULE 1
 
/* Define if compiling with the util_funcs/header_simple_table module files.  */
#define USING_UTIL_FUNCS_HEADER_SIMPLE_TABLE_MODULE 1
 
/* Define if compiling with the if-mib/ifTable/ifTable module files.  */
#define USING_IF_MIB_IFTABLE_IFTABLE_MODULE 1
 
/* Define if compiling with the if-mib/data_access/interface module files.  */
#define USING_IF_MIB_DATA_ACCESS_INTERFACE_MODULE 1
 
/* Define if compiling with the if-mib/ifTable/ifTable_interface module files.  */
#define USING_IF_MIB_IFTABLE_IFTABLE_INTERFACE_MODULE 1
 
/* Define if compiling with the if-mib/ifTable/ifTable_data_access module files.  */
#define USING_IF_MIB_IFTABLE_IFTABLE_DATA_ACCESS_MODULE 1
 
/* Define if compiling with the if-mib/data_access/interface_linux module files.  */
#define USING_IF_MIB_DATA_ACCESS_INTERFACE_LINUX_MODULE 1
 
/* Define if compiling with the if-mib/data_access/interface_ioctl module files.  */
#define USING_IF_MIB_DATA_ACCESS_INTERFACE_IOCTL_MODULE 1
 
/* Define if compiling with the ip-mib/data_access/ipaddress module files.  */
#define USING_IP_MIB_DATA_ACCESS_IPADDRESS_MODULE 1
 
/* Define if compiling with the ip-mib/data_access/ipaddress_common module files.  */
#define USING_IP_MIB_DATA_ACCESS_IPADDRESS_COMMON_MODULE 1
 
/* Define if compiling with the ip-mib/data_access/ipaddress_linux module files.  */
#define USING_IP_MIB_DATA_ACCESS_IPADDRESS_LINUX_MODULE 1
 
/* Define if compiling with the ip-mib/data_access/ipaddress_ioctl module files.  */
#define USING_IP_MIB_DATA_ACCESS_IPADDRESS_IOCTL_MODULE 1
 
