cmd_/home/turmio/Downloads/buildroot-2011.11/output/toolchain/linux/include/rdma/.install := perl scripts/headers_install.pl /home/turmio/Downloads/buildroot-2011.11/output/toolchain/linux-3.1.4/include/rdma /home/turmio/Downloads/buildroot-2011.11/output/toolchain/linux/include/rdma arm ib_user_cm.h ib_user_mad.h ib_user_sa.h ib_user_verbs.h rdma_netlink.h rdma_user_cm.h; perl scripts/headers_install.pl /home/turmio/Downloads/buildroot-2011.11/output/toolchain/linux-3.1.4/include/rdma /home/turmio/Downloads/buildroot-2011.11/output/toolchain/linux/include/rdma arm ; for F in ; do echo "\#include <asm-generic/$$F>" > /home/turmio/Downloads/buildroot-2011.11/output/toolchain/linux/include/rdma/$$F; done; touch /home/turmio/Downloads/buildroot-2011.11/output/toolchain/linux/include/rdma/.install
