cmd_/home/turmio/Downloads/buildroot-2011.11/output/toolchain/linux/include/linux/raid/.install := perl scripts/headers_install.pl /home/turmio/Downloads/buildroot-2011.11/output/toolchain/linux-3.1.4/include/linux/raid /home/turmio/Downloads/buildroot-2011.11/output/toolchain/linux/include/linux/raid arm md_p.h md_u.h; perl scripts/headers_install.pl /home/turmio/Downloads/buildroot-2011.11/output/toolchain/linux-3.1.4/include/linux/raid /home/turmio/Downloads/buildroot-2011.11/output/toolchain/linux/include/linux/raid arm ; for F in ; do echo "\#include <asm-generic/$$F>" > /home/turmio/Downloads/buildroot-2011.11/output/toolchain/linux/include/linux/raid/$$F; done; touch /home/turmio/Downloads/buildroot-2011.11/output/toolchain/linux/include/linux/raid/.install
