cmd_/home/turmio/Downloads/buildroot-2011.11/output/toolchain/linux/include/linux/wimax/.install := perl scripts/headers_install.pl /home/turmio/Downloads/buildroot-2011.11/output/toolchain/linux-3.1.4/include/linux/wimax /home/turmio/Downloads/buildroot-2011.11/output/toolchain/linux/include/linux/wimax arm i2400m.h; perl scripts/headers_install.pl /home/turmio/Downloads/buildroot-2011.11/output/toolchain/linux-3.1.4/include/linux/wimax /home/turmio/Downloads/buildroot-2011.11/output/toolchain/linux/include/linux/wimax arm ; for F in ; do echo "\#include <asm-generic/$$F>" > /home/turmio/Downloads/buildroot-2011.11/output/toolchain/linux/include/linux/wimax/$$F; done; touch /home/turmio/Downloads/buildroot-2011.11/output/toolchain/linux/include/linux/wimax/.install
