cmd_/home/turmio/Downloads/buildroot-2011.11/output/toolchain/linux/include/linux/usb/.install := perl scripts/headers_install.pl /home/turmio/Downloads/buildroot-2011.11/output/toolchain/linux-3.1.4/include/linux/usb /home/turmio/Downloads/buildroot-2011.11/output/toolchain/linux/include/linux/usb arm audio.h cdc.h ch11.h ch9.h functionfs.h g_printer.h gadgetfs.h midi.h tmc.h; perl scripts/headers_install.pl /home/turmio/Downloads/buildroot-2011.11/output/toolchain/linux-3.1.4/include/linux/usb /home/turmio/Downloads/buildroot-2011.11/output/toolchain/linux/include/linux/usb arm ; for F in ; do echo "\#include <asm-generic/$$F>" > /home/turmio/Downloads/buildroot-2011.11/output/toolchain/linux/include/linux/usb/$$F; done; touch /home/turmio/Downloads/buildroot-2011.11/output/toolchain/linux/include/linux/usb/.install
