cmd_/home/turmio/Downloads/buildroot-2011.11/output/toolchain/linux/include/mtd/.install := perl scripts/headers_install.pl /home/turmio/Downloads/buildroot-2011.11/output/toolchain/linux-3.1.4/include/mtd /home/turmio/Downloads/buildroot-2011.11/output/toolchain/linux/include/mtd arm inftl-user.h mtd-abi.h mtd-user.h nftl-user.h ubi-user.h; perl scripts/headers_install.pl /home/turmio/Downloads/buildroot-2011.11/output/toolchain/linux-3.1.4/include/mtd /home/turmio/Downloads/buildroot-2011.11/output/toolchain/linux/include/mtd arm ; for F in ; do echo "\#include <asm-generic/$$F>" > /home/turmio/Downloads/buildroot-2011.11/output/toolchain/linux/include/mtd/$$F; done; touch /home/turmio/Downloads/buildroot-2011.11/output/toolchain/linux/include/mtd/.install
