cmd_/home/turmio/Downloads/buildroot-2011.11/output/toolchain/linux/include/sound/.install := perl scripts/headers_install.pl /home/turmio/Downloads/buildroot-2011.11/output/toolchain/linux-3.1.4/include/sound /home/turmio/Downloads/buildroot-2011.11/output/toolchain/linux/include/sound arm asequencer.h asound.h asound_fm.h emu10k1.h hdsp.h hdspm.h sb16_csp.h sfnt_info.h; perl scripts/headers_install.pl /home/turmio/Downloads/buildroot-2011.11/output/toolchain/linux-3.1.4/include/sound /home/turmio/Downloads/buildroot-2011.11/output/toolchain/linux/include/sound arm ; for F in ; do echo "\#include <asm-generic/$$F>" > /home/turmio/Downloads/buildroot-2011.11/output/toolchain/linux/include/sound/$$F; done; touch /home/turmio/Downloads/buildroot-2011.11/output/toolchain/linux/include/sound/.install
